.. _cookbook:

The Cookbook
============

These scripts and Jupyter notebooks provide detailed demonstrations for
some of the functionality provide in the ``yt_astro_analysis`` package.
All of the data used in these recipes is freely available
`here <http://yt-project.org/data/>`_.

Example Scripts
---------------
.. toctree::
   :maxdepth: 2

   cosmological_analysis

.. _example-notebooks:

Example Notebooks
-----------------

- `Halo Analysis Example <https://github.com/yt-project/yt_astro_analysis/blob/master/doc/source/cookbook/Halo_Analysis.ipynb>`__

- `PPV Cube <https://github.com/yt-project/yt_astro_analysis/blob/master/doc/source/PPVCube.ipynb>`__

- `Sunyaev Zeldovich <https://github.com/yt-project/yt_astro_analysis/blob/master/doc/source/SZ_projections.ipynb>`__
